@@ -10,8 +10,8 @@
 
 """
 
-__title__ = "Django Swap EmailUser"
-__version__ = "0.1.7"
+__title__ = "Django Swap User"
+__version__ = "0.2.0"
 __author__ = "Artem Innokentiev"
 __license__ = "MIT"
 __copyright__ = "Copyright 2020 © Artem Innokentiev"
